@@ -1,4 +1,4 @@
-g.sib.plot = function(SLE,M,I,plottitle,nightsperpage=7,desiredtz="Europe/London") { #IMP,
+g.sib.plot = function(SLE,M,I,plottitle,nightsperpage=7,desiredtz="") { #IMP,
   A = SLE$output
   invalid = A$invalid
   night = A$night
@@ -11,7 +11,8 @@ g.sib.plot = function(SLE,M,I,plottitle,nightsperpage=7,desiredtz="Europe/London
   temptime = as.character(unlist(A$time))
   if (space == FALSE) {
     time = as.POSIXlt(temptime,tz=desiredtz,format="%Y-%m-%dT%H:%M:%S%z")
-    timeL = as.POSIXlt(strftime(as.character(S[1:nS,1]),tz=desiredtz,format="%Y-%m-%dT%H:%M:%S%z"))
+    # timeL = as.POSIXlt(strftime(as.character(S[1:nS,1]),tz=desiredtz,format="%Y-%m-%dT%H:%M:%S%z"))
+    timeL = iso8601chartime2POSIX(S[1:nS,1],tz=desiredtz)
   } else {
     time = as.POSIXlt(temptime,tz=desiredtz)
     timeL = as.POSIXlt(as.character(S[1:nS,1]),tz=desiredtz)
@@ -47,15 +48,25 @@ g.sib.plot = function(SLE,M,I,plottitle,nightsperpage=7,desiredtz="Europe/London
     temperature = temperature + abs(min(temperature,na.rm=TRUE))
   }
   temperature = temperature - min(temperature)
-  temperature = ((temperature/max(temperature)) *  180) - 90
+  temperature = (scale(temperature) * 70) - 90
   # transform light signal into something that is easy to plot on top of other data
   light = lightpeak
   light = light + min(light)
-  light = ((light/max(light)) *  200) - 90
+  light = (scale(light) * 210) - 120
   un = unique(night)
   if (length(which(un == 0 | is.na(un) == TRUE)) > 0) {
     un = un[-c(which(un == 0 | is.na(un) == TRUE))]
   }
+  ncolsleep = ncol(sleep)
+  if (length(ncolsleep) == 0) {
+    zeros = which(sleep == 0)
+    if (length(zeros) > 0) sleep[zeros] = NA
+  } else {
+    for (j in 1:ncolsleep) {
+      zeros = which(sleep[,j] == 0)
+      if (length(zeros) > 0) sleep[zeros,j] = NA
+    }
+  }
   for (i in 1:length(un)) {
     if (i == 1 | (i-1)/9 == round((i-1)/9)) {
       par(mfrow=c(9,1),mar=c(1,5,3,1),oma=c(2,0,0,0)) 
@@ -68,34 +79,35 @@ g.sib.plot = function(SLE,M,I,plottitle,nightsperpage=7,desiredtz="Europe/London
     if (length(qqq4) == 0) qqq4 = round(qqq2 / (ws2/ws3))
     if (qqq3 == 0) qqq3 = 1
     
-    plot(time[qqq1:qqq2],angle[qqq1:qqq2],type="l",xlab="",main=paste("Night: ",i," ",plottitle),
-         ylab="angle",   ylim=c(-250,90),xaxt="n",yaxt="n",cex.lab=0.8,cex.main=0.6,bty="n",lwd=0.4)
-    axis(2, at = c(-90,-45,0,45,90))
+    
+    #activity in the background, so go first
+    ENMOscaled = scale(ENMO[qqq1:qqq2],scale = abs(diff(range(ENMO[qqq1:qqq2])))/180) - 204
+    plot(time[qqq1:qqq2],ENMOscaled,type="l",xlab="",main=paste("Night: ",i," ",plottitle),col="grey",
+          ylab="angle (black)",   ylim=c(-250,90),xaxt="n",yaxt="n",cex.lab=0.8,cex.main=0.6,bty="n",lwd=0.4)
+    #temperature
+    lines(timeL[qqq3:qqq4],light[qqq3:qqq4],type="l",col="yellow",lty=1,lwd=1)
+    #light
+    lines(timeL[qqq3:qqq4],temperature[qqq3:qqq4],type="l",col="lightblue",lty=1,lwd=1)
+    
+    lines(time[qqq1:qqq2],angle[qqq1:qqq2],type="l",lwd=0.4,col="black")
+    axis(2, at = c(-90,0,90))
     r <- as.POSIXct(round(range(time[qqq1:qqq2]), "hours"))
     abline(h=0,lty=3,lwd=1.4,col="grey")
     abline(v=seq(r[1], r[2], by = "hour"),lty=3,lwd=1.4,col="grey")
-    
-    #temperature
-    lines(timeL[qqq3:qqq4],light[qqq3:qqq4],type="l",col="red",lty=1,lwd=0.6)
-    #light
-    lines(timeL[qqq3:qqq4],temperature[qqq3:qqq4],type="l",col="blue",lty=1,lwd=0.6)
-    
-    #activity
-    newENMO = ((ENMO[qqq1:qqq2] / 400) * 25)-150
-    lines(time[qqq1:qqq2],newENMO,type="l",lwd=0.4)
     #time axis
     axis.POSIXct(1, at = seq(r[1], r[2], by = "hour"), format = "%H")
+    
     if (length(ncol(sleep)) > 0) {
       ncolsleep = ncol(sleep)
       CL = rainbow(ncolsleep)
       for (j in 1:ncolsleep) {
-        lines(time[qqq1:qqq2],(-(240)+(sleep[qqq1:qqq2,j]*((80/ncolsleep)*j))),type="l",col=CL[j],lwd=0.6)
+        lines(time[qqq1:qqq2],(-(240)+(sleep[qqq1:qqq2,j]*((80/ncolsleep)*j))),type="l",col=CL[j],lwd=1)
       }
     } else {
       ncolsleep = 1
       CL = rainbow(ncolsleep)
       for (j in 1:ncolsleep) {
-        lines(time[qqq1:qqq2],(-(240)+(sleep[qqq1:qqq2]*((80/ncolsleep)*j))),type="l",col=CL[j],lwd=0.6)
+        lines(time[qqq1:qqq2],(-(240)+(sleep[qqq1:qqq2]*((80/ncolsleep)*j))),type="l",col=CL[j],lwd=1)
       }
     }
   }
